src.MEDS\_tabular\_automl.scripts.tabularize\_static
====================================================

.. automodule:: src.MEDS_tabular_automl.scripts.tabularize_static







   .. rubric:: Functions

   .. autosummary::

      main
